<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.


declare(strict_types=1);

namespace HANAModule\Controller;


use App\itnovum\openITCOCKPIT\Wizard\CreateService;
use App\itnovum\openITCOCKPIT\Wizard\UpdateHost;
use App\Model\Entity\Host;
use App\Model\Table\HostsTable;
use App\Model\Table\HosttemplatesTable;
use App\Model\Table\ServicesTable;
use App\Model\Table\ServicetemplatesTable;
use App\Model\Table\WizardAssignmentsTable;
use Cake\Http\Exception\NotFoundException;
use Cake\ORM\TableRegistry;
use Cake\Utility\Hash;
use HANAModule\Form\SapHanaForm;
use itnovum\openITCOCKPIT\Core\ValueObjects\User;

/**
 * Class WizardsController
 * @package HANAModule\Controller
 */
class WizardsController extends AppController {


    /**
     * @param null $hostId
     */
    public function saphana($hostId = null) {
        if (!$this->isApiRequest()) {
            //Only ship HTML template for angular
            return;
        }

        /** @var WizardAssignmentsTable $WizardAssignmentsTable */
        $WizardAssignmentsTable = TableRegistry::getTableLocator()->get('WizardAssignments');
        $wizards = $WizardAssignmentsTable->getAvailableWizards($this->PERMISSIONS);
        /** @var ServicesTable $ServicesTable */
        $ServicesTable = TableRegistry::getTableLocator()->get('Services');
        /** @var HostsTable $HostsTable */
        $HostsTable = TableRegistry::getTableLocator()->get('Hosts');

        if ($this->request->is('get') && $this->isAngularJsRequest()) {
            if (!$HostsTable->existsById($hostId)) {
                throw new NotFoundException();
            }
            $host = $HostsTable->getHostByIdForPermissionCheck($hostId);
            if (!$this->allowedByContainerId($host->getContainerIds())) {
                $this->render403();
                return;
            }

            $hostCustomVariables = $HostsTable->get($hostId, [
                'contain' => [
                    'Customvariables'
                ]
            ])->getCustomvariablesForCfg();

            $dbuser = '';
            if (!empty($hostCustomVariables['_DBUSER'])) {
                $dbuser = $hostCustomVariables['_DBUSER'];
            }
            $dbpassword = '';
            if (!empty($hostCustomVariables['_DBPASSWORD'])) {
                $dbpassword = $hostCustomVariables['_DBPASSWORD'];
            }
            $dbtenantport = '';
            if (!empty($hostCustomVariables['_HANATENANTPORT'])) {
                $dbtenantport = $hostCustomVariables['_HANATENANTPORT'];
            }
            $dbsystemport = '';
            if (!empty($hostCustomVariables['_HANASYSTEMPORT'])) {
                $dbsystemport = $hostCustomVariables['_HANASYSTEMPORT'];
            }
            $this->set('dbuser', $dbuser);
            $this->set('dbpassword', $dbpassword);
            $this->set('dbtenantport', $dbtenantport);
            $this->set('dbsystemport', $dbsystemport);

            $typeId = $this->request->getQuery('typeId');
            //Return sap hana wizard data
            $servicetemplates = [];
            $wizardAssignments = [];
            $sapHanaData = $wizards[$typeId] ?? null;
            if ($sapHanaData) {
                if ($WizardAssignmentsTable->existsByUuidAndTypeId($sapHanaData['uuid'], $typeId)) {
                    $wizardAssignments = Hash::merge($sapHanaData, $WizardAssignmentsTable->getWizardByUuidForEdit($sapHanaData['uuid']));
                }
            }
            if (!empty($wizardAssignments['servicetemplates']['_ids'])) {
                /** @var ServicetemplatesTable $ServicetemplatesTable */
                $ServicetemplatesTable = TableRegistry::getTableLocator()->get('Servicetemplates');
                $servicetemplates = $ServicetemplatesTable->getServicetemplatesFoWizardDeploy(
                    $wizardAssignments['servicetemplates']['_ids'],
                    $this->MY_RIGHTS
                );
            }
            $servicesNamesForExistCheck = $ServicesTable->getServiceNamesByHostIdForWizard($hostId);


            $this->set('servicetemplates', $servicetemplates);
            $this->set('servicesNamesForExistCheck', $servicesNamesForExistCheck);

            $this->viewBuilder()->setOption('serialize', [
                'servicetemplates',
                'servicesNamesForExistCheck',
                'dbuser',
                'dbpassword',
                'dbtenantport',
                'dbsystemport'
            ]);
            return;
        }
        if ($this->request->is('post') && $this->isAngularJsRequest()) {
            $hostId = $this->request->getData('host_id', 0);
            $typeId = $this->request->getData('typeId');

            if (!$HostsTable->existsById($hostId)) {
                throw new NotFoundException();
            }
            $host = $HostsTable->getHostByIdForPermissionCheck($hostId);
            if (!$this->allowedByContainerId($host->getContainerIds())) {
                $this->render403();
                return;
            }
            $SapHanaForm = new SapHanaForm();
            $data = $this->request->getData(null, []);
            $SapHanaForm->execute($data);

            if (!empty($SapHanaForm->getErrors())) {
                $this->response = $this->response->withStatus(400);
                $this->set('error', $SapHanaForm->getErrors());
                $this->viewBuilder()->setOption('serialize', ['error']);
                return;
            }

            //Wizard validation successfully - update host and create services
            $User = new User($this->getUser());

            /** @var HosttemplatesTable $HosttemplatesTable */
            $HosttemplatesTable = TableRegistry::getTableLocator()->get('Hosttemplates');

            // Get host and host template for merge
            $host = $HostsTable->getHostForEdit($hostId);
            $hosttemplate = $HosttemplatesTable->getHosttemplateForDiff($host['Host']['hosttemplate_id']);

            //Update custom variables
            $hostCustomVariablestoCheck = [
                'DBUSER'         => 'dbuser',
                'DBPASSWORD'     => 'dbpassword'
            ];

            if ($typeId === 'sap-hana-tenant') {
                $hostCustomVariablestoCheck['HANATENANTPORT'] = 'dbtenantport';    //SAP HANA Tenant Database only
            }

            if ($typeId === 'sap-hana-system') {
                $hostCustomVariablestoCheck['HANASYSTEMPORT'] = 'dbsystemport';    //SAP HANA System Database only
            }
            //Update host with changelog
            $hostEntity = UpdateHost::save(
                $host,
                $hosttemplate,
                $data,
                $hostCustomVariablestoCheck,
                $HostsTable,
                $User
            );

            if ($hostEntity instanceof Host) {
                //Host updated successfully - create services
                /** @var ServicetemplatesTable $ServicetemplatesTable */
                $ServicetemplatesTable = TableRegistry::getTableLocator()->get('Servicetemplates');

                // Save default SAP services
                CreateService::saveMany(
                    $hostEntity,
                    $data['services'],
                    $data,
                    [],
                    $HostsTable,
                    $HosttemplatesTable,
                    $ServicesTable,
                    $ServicetemplatesTable,
                    $User
                );
            }
        }
        return;
    }
}