<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.

// in src/Form/SapHanaForm.php
namespace HANAModule\Form;

use Cake\Form\Form;
use Cake\Form\Schema;
use Cake\Validation\Validator;

/**
 * Class SapHanaForm
 * @package HANAModule\Form
 */
class SapHanaForm extends Form {
    protected function _buildSchema(Schema $schema): Schema {
        return $schema
            ->addField('dbuser', ['type' => 'string'])
            ->addField('dbpassword', ['type' => 'string'])
            ->addField('dbsystemport', ['type' => 'integer'])
            ->addField('dbtenantport', ['type' => 'integer'])
            ->addField('services', ['type' => 'array']);
    }

    public function validationDefault(Validator $validator): Validator {
        $validator
            ->requirePresence('dbuser')
            ->allowEmptyString('dbuser', null, false);
        $validator
            ->requirePresence('dbpassword')
            ->allowEmptyString('dbpassword', null, false);
        $validator
            ->scalar('dbsystemport')
            ->range('dbsystemport', [0, 65535], __('The port numbers in the range from 0 to 65535'))
            ->requirePresence('dbsystemport')
            ->allowEmptyString('dbsystemport', null, function ($context) {
                return $context['data']['typeId'] === 'sap-hana-tenant';
            });
        $validator
            ->scalar('dbtenantport')
            ->range('dbtenantport', [0, 65535], __('The port numbers in the range from 0 to 65535'))
            ->requirePresence('dbtenantport')
            ->allowEmptyString('dbtenantport', null, function ($context) {
                return $context['data']['typeId'] === 'sap-hana-system';
            });
        $validator
            ->requirePresence('services')
            ->notEmptyArray('services', __('You have to select at least one service'), false);

        return $validator;
    }
}