<?php
// Copyright (C) <2015>  <it-novum GmbH>
//
// This file is dual licensed
//
// 1.
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, version 3 of the License.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// 2.
//  If you purchased an openITCOCKPIT Enterprise Edition you can use this file
//  under the terms of the openITCOCKPIT Enterprise Edition license agreement.
//  License agreement and license key will be shipped with the order
//  confirmation.

namespace HANAModule\Lib\InitialDatabase;

use App\Model\Table\CommandsTable;
use App\Model\Table\ServicetemplategroupsTable;
use App\Model\Table\ServicetemplatesTable;
use App\Model\Table\WizardAssignmentsTable;
use itnovum\openITCOCKPIT\InitialDatabase\Importer;

/**
 * Class TemplateImport
 * @package HANAModule\Lib\InitialDatabase
 */
class TemplateImport extends Importer {
    /**
     * @var CommandsTable
     */
    private $CommandsTable;

    /**
     * @var ServicetemplatesTable
     */
    private $ServicetemplatesTable;

    /**
     * @var ServicetemplategroupsTable
     */
    private $ServicetemplategroupsTable;

    /**
     * @var WizardAssignmentsTable
     */
    private $WizardAssignmentsTable;

    /**
     * @var array
     */
    private $mapping = [];

    /**
     * TemplateImport constructor.
     * @param CommandsTable $CommandsTable
     * @param ServicetemplatesTable $ServicetemplatesTable
     * @param ServicetemplategroupsTable $ServicetemplategroupsTable
     * @param WizardAssignmentsTable $WizardAssignmentsTable
     */
    public function __construct(CommandsTable $CommandsTable, ServicetemplatesTable $ServicetemplatesTable, ServicetemplategroupsTable $ServicetemplategroupsTable, WizardAssignmentsTable $WizardAssignmentsTable) {
        $this->CommandsTable = $CommandsTable;
        $this->ServicetemplatesTable = $ServicetemplatesTable;
        $this->ServicetemplategroupsTable = $ServicetemplategroupsTable;
        $this->WizardAssignmentsTable = $WizardAssignmentsTable;
    }

    /**
     * @return bool
     */
    public function import() {
        $data = $this->getData();
        foreach ($data['Commands'] as $command) {
            if (isset($command['uuid']) && !$this->CommandsTable->existsByUuid($command['uuid'])) {
                $entity = $this->CommandsTable->newEntity($command);
                $this->CommandsTable->save($entity);
            }
        }
        $this->mapping['servicetemplates'] = [];

        foreach ($data['Servicetemplates'] as $servicetemplate) {
            if ($this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                $existingServicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplate['uuid']);
                $this->mapping['servicetemplates'][$servicetemplate['uuid']] = $existingServicetemplate['Servicetemplate']['id'];
                //skip current template if it already exists
                continue;
            }
            if (isset($servicetemplate['uuid']) && !$this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                if (isset($servicetemplate['command_id']) && $this->CommandsTable->existsByUuid($servicetemplate['command_id'])) {
                    $command = $this->CommandsTable->getCommandByUuid($servicetemplate['command_id'], true, false)[0];
                    $servicetemplate['command_id'] = $command['id'];
                    if (!empty($servicetemplate['servicetemplatecommandargumentvalues']) && !empty($command['commandarguments'])) {
                        foreach ($servicetemplate['servicetemplatecommandargumentvalues'] as $templateArgumentKey => $templateArgumentValue) {
                            $servicetemplate['servicetemplatecommandargumentvalues'][$templateArgumentKey] = [
                                'commandargument_id' => $this->getCommandArgumentIdByName($templateArgumentValue['commandargument_id'], $command['commandarguments']),
                                'value'              => $templateArgumentValue['value'],
                            ];
                        }
                    }
                    $entity = $this->ServicetemplatesTable->newEntity($servicetemplate);
                    $this->ServicetemplatesTable->save($entity);
                    $this->mapping['servicetemplates'][$entity->get('uuid')] = $entity->get('id');
                }
            }
        }

        foreach ($data['Servicetemplategroups'] as $servicetemplategroup) {
            if ($this->ServicetemplategroupsTable->existsByUuid($servicetemplategroup['uuid'])) {
                //skip current template if its already exists
                continue;
            }

            if (!empty($this->mapping['servicetemplates'])) {
                foreach ($servicetemplategroup['servicetemplates'] as $key => $servicetemplate) {
                    $currIdAsUuid = $servicetemplate['id'];
                    if (isset($this->mapping['servicetemplates'][$currIdAsUuid])) {
                        $servicetemplategroup['servicetemplates']['_ids'][] = $this->mapping['servicetemplates'][$currIdAsUuid];
                    }

                }
            }

            $entity = $this->ServicetemplategroupsTable->newEntity($servicetemplategroup);
            $this->ServicetemplategroupsTable->save($entity);
        }


        if (!empty($data['Wizardassignment'])) {
            foreach ($data['Wizardassignment'] as $wizardassignment) {
                $wizardassignmentEntity['servicetemplates']['_ids'] = [];
                $wizardassignmentEntity['uuid'] = $wizardassignment['uuid'];
                $wizardassignmentEntity['type_id'] = $wizardassignment['type_id'];
                foreach ($wizardassignment['servicetemplates']['_ids'] as $servicetemplateUuid) {
                    $servicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplateUuid);
                    if (isset($servicetemplate['Servicetemplate']) && isset($servicetemplate['Servicetemplate']['id'])) {
                        $wizardassignmentEntity['servicetemplates']['_ids'][] = $servicetemplate['Servicetemplate']['id'];
                    }
                }
                if (!$this->WizardAssignmentsTable->existsByUuidAndTypeId($wizardassignmentEntity['uuid'], $wizardassignmentEntity['type_id'])) {
                    $entity = $this->WizardAssignmentsTable->newEntity($wizardassignmentEntity);
                    $this->WizardAssignmentsTable->save($entity);
                } else {
                    $existingAssignment = $this->WizardAssignmentsTable->getWizardByUuidForEdit($wizardassignmentEntity['uuid']);
                    foreach (array_diff($wizardassignmentEntity['servicetemplates']['_ids'], $existingAssignment['servicetemplates']['_ids']) as $missingServicetemplateId) {
                        $existingAssignment['servicetemplates']['_ids'][] = $missingServicetemplateId;
                    }
                    $entity = $this->WizardAssignmentsTable->get($existingAssignment['id']);
                    $entity = $this->WizardAssignmentsTable->patchEntity($entity, $existingAssignment);
                    $this->WizardAssignmentsTable->save($entity);
                }
            }
        }
        return true;
    }

    /**
     * @return array
     */
    public function getData() {
        return [
            'Commands'              => $this->getCommandsData(),
            'Servicetemplates'      => $this->getServicetemplatesData(),
            'Servicetemplategroups' => $this->getServicetemplategroupsData(),
            'Wizardassignment'      => $this->getWizardAssignmentData()
        ];
    }

    /**
     * @return array
     */
    public function getCommandsData() {
        $data = [
            0 =>
                [
                    'name'             => 'check_hana_system',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANASYSTEMPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=$ARG1$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '7c9a3cae-a5b8-4886-8ace-c13f0e3391d4',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Mode',
                                ],
                        ],
                ],
            1 =>
                [
                    'name'             => 'check_hana_system_usage',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANASYSTEMPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=usage --type $ARG1$ --warning $ARG2$ --critical $ARG3$ --unit percent',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => 'd1923588-3407-4ecf-bd26-9ef92bae5aa0',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Type',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Warning',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'Critical',
                                ],
                        ],
                ],
            2 =>
                [
                    'name'             => 'check_hana_system_backup',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANASYSTEMPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=$ARG1$ --warning $ARG2$ --critical $ARG3$ --unit hours',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '5c1d86d4-0f18-422c-b99a-4ee30d204d14',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Mode',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Warning',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'Critical',
                                ],
                        ],
                ],
            3 =>
                [
                    'name'             => 'check_hana_system_threshold',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANASYSTEMPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=$ARG1$ --warning $ARG2$ --critical $ARG3$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '5d5642eb-d4ef-4acc-9e08-eb233833e5d4',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Mode',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Warning',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'Critical',
                                ],
                        ],
                ],
            4 =>
                [
                    'name'             => 'check_hana_system_alerts',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANASYSTEMPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=currentalerts --alertid=$ARG1$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '448cdb0e-7b4f-4966-be64-9fe12083dce7',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Alertid',
                                ],
                        ],
                ],
            5 =>
                [
                    'name'             => 'check_hana_tenant',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANATENANTPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=$ARG1$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '2bbb9dc6-ca10-487e-8602-df81114799a0',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Mode',
                                ],
                        ],
                ],
            6 =>
                [
                    'name'             => 'check_hana_tenant_usage',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANATENANTPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=usage --type $ARG1$ --warning $ARG2$ --critical $ARG3$ --unit percent',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '4f16070d-c407-4c03-8e82-2aaa4891cc6c',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Type',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Warning',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'Critical',
                                ],
                        ],
                ],
            7 =>
                [
                    'name'             => 'check_hana_tenant_backup',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANATENANTPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=$ARG1$ --warning $ARG2$ --critical $ARG3$ --unit hours',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '0e654686-0737-4ad5-bab1-ec1088d455f4',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Mode',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Warning',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'Critical',
                                ],
                        ],
                ],
            8 =>
                [
                    'name'             => 'check_hana_tenant_threshold',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANATENANTPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=$ARG1$ --warning $ARG2$ --critical $ARG3$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => 'e63c62e0-7098-4c0d-a018-ce8391635488',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Mode',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Warning',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'Critical',
                                ],
                        ],
                ],
            9 =>
                [
                    'name'             => 'check_hana_tenant_alerts',
                    'command_line'     => '$USER1$/check_sap_hana.py --hostname=$HOSTADDRESS$ --port=$_HOSTHANATENANTPORT$ --username=$_HOSTDBUSER$ --password=\'$_HOSTDBPASSWORD$\' --method=currentalerts --alertid=$ARG1$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '67c052bf-8dc8-4feb-a9fc-0d2bed0c6ff8',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Alertid',
                                ],
                        ],
                ],
        ];
        return $data;
    }


    /**
     * @return array
     */
    public function getServicetemplatesData() {
        $data = [
            0  =>
                [
                    'uuid'                                      => '06d90cfc-87d8-4d80-bf1a-0347d769bf4d',
                    'template_name'                             => 'HANA_SYSTEM_ALERTS',
                    'name'                                      => 'HANA System Alert ID',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '448cdb0e-7b4f-4966-be64-9fe12083dce7',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            1  =>
                [
                    'uuid'                                      => 'ddf35bcc-baab-4006-bea8-e075c4cf2312',
                    'template_name'                             => 'HANA_SYSTEM_BACKUP_AGE',
                    'name'                                      => 'HANA System Backup-Age',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '5c1d86d4-0f18-422c-b99a-4ee30d204d14',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'backupage',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '48',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '72',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            2  =>
                [
                    'uuid'                                      => '6d8c7ea2-cebf-47fb-8d2d-9cc553f19bc3',
                    'template_name'                             => 'HANA_SYSTEM_LOG_BACKUP_AGE',
                    'name'                                      => 'HANA System LogBackup-Age',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '5c1d86d4-0f18-422c-b99a-4ee30d204d14',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'logbackupage',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '48',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '72',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            3  =>
                [
                    'uuid'                                      => '5f29f279-4d45-486f-b581-c9517dc0c122',
                    'template_name'                             => 'HANA_SYSTEM_CONNECTION_TIME',
                    'name'                                      => 'HANA System Connection-Time',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '5d5642eb-d4ef-4acc-9e08-eb233833e5d4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'connectiontime',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '5',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            4  =>
                [
                    'uuid'                                      => '097942a9-f582-4fd0-8a90-5e176de0f251',
                    'template_name'                             => 'HANA_SYSTEM_DATA_BACKUP_THROUGHPUT',
                    'name'                                      => 'HANA System Data Backup Throughput',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '7c9a3cae-a5b8-4886-8ace-c13f0e3391d4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'databackupthroughput',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            5  =>
                [
                    'uuid'                                      => '78c01f74-07e6-40fb-a6c7-1dec22e22946',
                    'template_name'                             => 'HANA_SYSTEM_LOGSEGMENTS_USAGE',
                    'name'                                      => 'HANA System Log Segments usage',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '5d5642eb-d4ef-4acc-9e08-eb233833e5d4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'logsegments',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2:',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '2:',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            6  =>
                [
                    'uuid'                                      => '9ba38438-45a1-43b1-a24b-c17b53d49afe',
                    'template_name'                             => 'HANA_SYSTEM_MEMORY_USAGE',
                    'name'                                      => 'HANA System Memory-usage',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '5d5642eb-d4ef-4acc-9e08-eb233833e5d4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'memoryusage',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '95',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            7  =>
                [
                    'uuid'                                      => '2bdc32a7-ac7b-4fcf-b12c-63d6a4a4a3a5',
                    'template_name'                             => 'HANA_SYSTEM_PENDING_SESSIONS',
                    'name'                                      => 'HANA System Pending sessions',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '5d5642eb-d4ef-4acc-9e08-eb233833e5d4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'pendingsession',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '5',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            8  =>
                [
                    'uuid'                                      => '5d86503b-5e75-45a7-9262-06ce26720a70',
                    'template_name'                             => 'HANA_SYSTEM_REPLICATION',
                    'name'                                      => 'HANA System Replication',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '7c9a3cae-a5b8-4886-8ace-c13f0e3391d4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'replication',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            9  =>
                [
                    'uuid'                                      => '39687003-3837-45b7-94c4-47b40cd82bc7',
                    'template_name'                             => 'HANA_SYSTEM_SERVICES',
                    'name'                                      => 'HANA System Services',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '7c9a3cae-a5b8-4886-8ace-c13f0e3391d4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'services',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            10 =>
                [
                    'uuid'                                      => '9babab95-a325-42b1-877e-34f1d47292c0',
                    'template_name'                             => 'HANA_SYSTEM_USAGE_LOG',
                    'name'                                      => 'HANA System Usage Log',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'd1923588-3407-4ecf-bd26-9ef92bae5aa0',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'log',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '95',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            11 =>
                [
                    'uuid'                                      => 'e74d11dc-99d4-4ccb-8944-0a810dcb5b88',
                    'template_name'                             => 'HANA_SYSTEM_USAGE_SIZE',
                    'name'                                      => 'HANA System Usage SIZE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'd1923588-3407-4ecf-bd26-9ef92bae5aa0',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'size',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '95',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            12 =>
                [
                    'uuid'                                      => '04c1f4d5-19f2-4909-94fd-158d9309deb3',
                    'template_name'                             => 'HANA_SYSTEM_USAGE_TRACE',
                    'name'                                      => 'HANA System Usage Trace',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'd1923588-3407-4ecf-bd26-9ef92bae5aa0',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'trace',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '95',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            13 =>
                [
                    'uuid'                                      => 'eea92b1e-3d7b-4922-b6cd-bc0b5ef9c951',
                    'template_name'                             => 'HANA_TENANT_ALERTS',
                    'name'                                      => 'HANA Tenant Alert ID',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '67c052bf-8dc8-4feb-a9fc-0d2bed0c6ff8',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            14 =>
                [
                    'uuid'                                      => '2a645ef8-dbc1-4b4b-8b46-038cccb14f8c',
                    'template_name'                             => 'HANA_TENANT_BACKUP_AGE',
                    'name'                                      => 'HANA Tenant Backup-Age',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '0e654686-0737-4ad5-bab1-ec1088d455f4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'backupage',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '48',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '72',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            15 =>
                [
                    'uuid'                                      => '1118b4bb-d993-468a-a873-b43cd13c265a',
                    'template_name'                             => 'HANA_TENANT_LOG_BACKUP_AGE',
                    'name'                                      => 'HANA Tenant LogBackup-Age',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '0e654686-0737-4ad5-bab1-ec1088d455f4',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'logbackupage',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '48',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '72',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            16 =>
                [
                    'uuid'                                      => 'dfb27713-856f-4b8a-a5f6-d24e92635650',
                    'template_name'                             => 'HANA_TENANT_CONNECTION_TIME',
                    'name'                                      => 'HANA Tenant Connection-Time',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'e63c62e0-7098-4c0d-a018-ce8391635488',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'connectiontime',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '5',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            17 =>
                [
                    'uuid'                                      => '797c9184-ed05-4d57-acf0-ce964732f0f2',
                    'template_name'                             => 'HANA_TENANT_DATA_BACKUP_THROUGHPUT',
                    'name'                                      => 'HANA Tenant Data Backup Throughput',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '2bbb9dc6-ca10-487e-8602-df81114799a0',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'databackupthroughput',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            18 =>
                [
                    'uuid'                                      => '904fd2eb-fd73-45cb-99e9-86b2b46224f2',
                    'template_name'                             => 'HANA_TENANT_LOGSEGMENTS_USAGE',
                    'name'                                      => 'HANA Tenant Log Segments usage',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'e63c62e0-7098-4c0d-a018-ce8391635488',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'logsegments',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2:',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '2:',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            19 =>
                [
                    'uuid'                                      => 'dcb1f30b-1663-4b8d-8eb1-321b90abca7e',
                    'template_name'                             => 'HANA_TENANT_MEMORY_USAGE',
                    'name'                                      => 'HANA Tenant Memory-usage',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'e63c62e0-7098-4c0d-a018-ce8391635488',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'memoryusage',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '95',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            20 =>
                [
                    'uuid'                                      => 'a04ce47d-b234-4d93-9da0-b6a205d7cf9c',
                    'template_name'                             => 'HANA_TENANT_PENDING_SESSIONS',
                    'name'                                      => 'HANA Tenant Pending sessions',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'e63c62e0-7098-4c0d-a018-ce8391635488',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'pendingsession',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '5',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            21 =>
                [
                    'uuid'                                      => '24c470c8-ab3b-4537-8f3b-814a0b245292',
                    'template_name'                             => 'HANA_TENANT_REPLICATION',
                    'name'                                      => 'HANA Tenant Replication',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '2bbb9dc6-ca10-487e-8602-df81114799a0',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'replication',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            22 =>
                [
                    'uuid'                                      => '0ddd7e66-1532-4c5b-8307-75e1d3b1f370',
                    'template_name'                             => 'HANA_TENANT_SERVICES',
                    'name'                                      => 'HANA Tenant Services',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '2bbb9dc6-ca10-487e-8602-df81114799a0',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'services',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            23 =>
                [
                    'uuid'                                      => '91e4568f-ce5d-4330-9855-535b3c9e2359',
                    'template_name'                             => 'HANA_TENANT_USAGE_LOG',
                    'name'                                      => 'HANA Tenant Usage Log',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '4f16070d-c407-4c03-8e82-2aaa4891cc6c',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'log',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '95',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            24 =>
                [
                    'uuid'                                      => 'd6341ccc-1d82-46e2-bc38-3c136d047cd1',
                    'template_name'                             => 'HANA_TENANT_USAGE_SIZE',
                    'name'                                      => 'HANA Tenant Usage SIZE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '4f16070d-c407-4c03-8e82-2aaa4891cc6c',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'size',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '95',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            25 =>
                [
                    'uuid'                                      => '1401802d-0f14-46bf-b108-5e25dd3b02ac',
                    'template_name'                             => 'HANA_TENANT_USAGE_TRACE',
                    'name'                                      => 'HANA Tenant Usage Trace',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '4f16070d-c407-4c03-8e82-2aaa4891cc6c',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => null,
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => '3600',
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2021-03-26 12:20:00',
                    'modified'                                  => '2021-03-26 12:20:00',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'trace',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '95',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
        ];
        return $data;
    }

    public function getServicetemplategroupsData() {
        $data = [
            0 =>
                [
                    'uuid'             => 'fd7afffb-f3be-42d9-80e8-9f52a1e664cc',
                    'description'      => '',
                    'servicetemplates' =>
                        [
                            0  =>
                                [
                                    'id'   => '06d90cfc-87d8-4d80-bf1a-0347d769bf4d',
                                    'uuid' => '06d90cfc-87d8-4d80-bf1a-0347d769bf4d',
                                ],
                            1  =>
                                [
                                    'id'   => 'ddf35bcc-baab-4006-bea8-e075c4cf2312',
                                    'uuid' => 'ddf35bcc-baab-4006-bea8-e075c4cf2312',
                                ],
                            2  =>
                                [
                                    'id'   => '6d8c7ea2-cebf-47fb-8d2d-9cc553f19bc3',
                                    'uuid' => '6d8c7ea2-cebf-47fb-8d2d-9cc553f19bc3',
                                ],
                            3  =>
                                [
                                    'id'   => '5f29f279-4d45-486f-b581-c9517dc0c122',
                                    'uuid' => '5f29f279-4d45-486f-b581-c9517dc0c122',
                                ],
                            4  =>
                                [
                                    'id'   => '097942a9-f582-4fd0-8a90-5e176de0f251',
                                    'uuid' => '097942a9-f582-4fd0-8a90-5e176de0f251',
                                ],
                            5  =>
                                [
                                    'id'   => '78c01f74-07e6-40fb-a6c7-1dec22e22946',
                                    'uuid' => '78c01f74-07e6-40fb-a6c7-1dec22e22946',
                                ],
                            6  =>
                                [
                                    'id'   => '9ba38438-45a1-43b1-a24b-c17b53d49afe',
                                    'uuid' => '9ba38438-45a1-43b1-a24b-c17b53d49afe',
                                ],
                            7  =>
                                [
                                    'id'   => '2bdc32a7-ac7b-4fcf-b12c-63d6a4a4a3a5',
                                    'uuid' => '2bdc32a7-ac7b-4fcf-b12c-63d6a4a4a3a5',
                                ],
                            8  =>
                                [
                                    'id'   => '5d86503b-5e75-45a7-9262-06ce26720a70',
                                    'uuid' => '5d86503b-5e75-45a7-9262-06ce26720a70',
                                ],
                            9  =>
                                [
                                    'id'   => '39687003-3837-45b7-94c4-47b40cd82bc7',
                                    'uuid' => '39687003-3837-45b7-94c4-47b40cd82bc7',
                                ],
                            10 =>
                                [
                                    'id'   => '9babab95-a325-42b1-877e-34f1d47292c0',
                                    'uuid' => '9babab95-a325-42b1-877e-34f1d47292c0',
                                ],
                            11 =>
                                [
                                    'id'   => 'e74d11dc-99d4-4ccb-8944-0a810dcb5b88',
                                    'uuid' => 'e74d11dc-99d4-4ccb-8944-0a810dcb5b88',
                                ],
                            12 =>
                                [
                                    'id'   => '04c1f4d5-19f2-4909-94fd-158d9309deb3',
                                    'uuid' => '04c1f4d5-19f2-4909-94fd-158d9309deb3',
                                ],
                        ],
                    'container'        =>
                        [
                            'name'             => 'HANA System Monitoring',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ],
                ],
            1 =>
                [
                    'uuid'             => '59adcd4f-7a4b-46ab-8b84-72c137a1b1ba',
                    'description'      => '',
                    'servicetemplates' =>
                        [
                            0  =>
                                [
                                    'id'   => 'eea92b1e-3d7b-4922-b6cd-bc0b5ef9c951',
                                    'uuid' => 'eea92b1e-3d7b-4922-b6cd-bc0b5ef9c951',
                                ],
                            1  =>
                                [
                                    'id'   => '2a645ef8-dbc1-4b4b-8b46-038cccb14f8c',
                                    'uuid' => '2a645ef8-dbc1-4b4b-8b46-038cccb14f8c',
                                ],
                            2  =>
                                [
                                    'id'   => '1118b4bb-d993-468a-a873-b43cd13c265a',
                                    'uuid' => '1118b4bb-d993-468a-a873-b43cd13c265a',
                                ],
                            3  =>
                                [
                                    'id'   => 'dfb27713-856f-4b8a-a5f6-d24e92635650',
                                    'uuid' => 'dfb27713-856f-4b8a-a5f6-d24e92635650',
                                ],
                            4  =>
                                [
                                    'id'   => '797c9184-ed05-4d57-acf0-ce964732f0f2',
                                    'uuid' => '797c9184-ed05-4d57-acf0-ce964732f0f2',
                                ],
                            5  =>
                                [
                                    'id'   => '904fd2eb-fd73-45cb-99e9-86b2b46224f2',
                                    'uuid' => '904fd2eb-fd73-45cb-99e9-86b2b46224f2',
                                ],
                            6  =>
                                [
                                    'id'   => 'dcb1f30b-1663-4b8d-8eb1-321b90abca7e',
                                    'uuid' => 'dcb1f30b-1663-4b8d-8eb1-321b90abca7e',
                                ],
                            7  =>
                                [
                                    'id'   => 'a04ce47d-b234-4d93-9da0-b6a205d7cf9c',
                                    'uuid' => 'a04ce47d-b234-4d93-9da0-b6a205d7cf9c',
                                ],
                            8  =>
                                [
                                    'id'   => '24c470c8-ab3b-4537-8f3b-814a0b245292',
                                    'uuid' => '24c470c8-ab3b-4537-8f3b-814a0b245292',
                                ],
                            9  =>
                                [
                                    'id'   => '0ddd7e66-1532-4c5b-8307-75e1d3b1f370',
                                    'uuid' => '0ddd7e66-1532-4c5b-8307-75e1d3b1f370',
                                ],
                            10 =>
                                [
                                    'id'   => '91e4568f-ce5d-4330-9855-535b3c9e2359',
                                    'uuid' => '91e4568f-ce5d-4330-9855-535b3c9e2359',
                                ],
                            11 =>
                                [
                                    'id'   => 'd6341ccc-1d82-46e2-bc38-3c136d047cd1',
                                    'uuid' => 'd6341ccc-1d82-46e2-bc38-3c136d047cd1',
                                ],
                            12 =>
                                [
                                    'id'   => '1401802d-0f14-46bf-b108-5e25dd3b02ac',
                                    'uuid' => '1401802d-0f14-46bf-b108-5e25dd3b02ac',
                                ],
                        ],
                    'container'        =>
                        [
                            'name'             => 'HANA Tenant Monitoring',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ]
                ]
        ];

        return $data;
    }

    /**
     * @param string $name
     * @param array $commandarguments
     * @return bool|mixed
     */
    public function getCommandArgumentIdByName(string $name, array $commandarguments) {
        foreach ($commandarguments as $commandargument) {
            if (isset($commandargument['name']) && $commandargument['name'] === $name) {
                return $commandargument['id'];
            }
        }
        return false;
    }

    /**
     * @return array
     */
    public function getWizardAssignmentData() {
        $data = [
            [
                'uuid'             => '27e11677-d778-4cdc-bdbc-e0dc298d0218',
                'type_id'          => 'sap-hana-system',
                'servicetemplates' => [
                    '_ids' => [
                        '06d90cfc-87d8-4d80-bf1a-0347d769bf4d',
                        'ddf35bcc-baab-4006-bea8-e075c4cf2312',
                        '6d8c7ea2-cebf-47fb-8d2d-9cc553f19bc3',
                        '5f29f279-4d45-486f-b581-c9517dc0c122',
                        '097942a9-f582-4fd0-8a90-5e176de0f251',
                        '78c01f74-07e6-40fb-a6c7-1dec22e22946',
                        '9ba38438-45a1-43b1-a24b-c17b53d49afe',
                        '2bdc32a7-ac7b-4fcf-b12c-63d6a4a4a3a5',
                        '5d86503b-5e75-45a7-9262-06ce26720a70',
                        '39687003-3837-45b7-94c4-47b40cd82bc7',
                        '9babab95-a325-42b1-877e-34f1d47292c0',
                        'e74d11dc-99d4-4ccb-8944-0a810dcb5b88',
                        '04c1f4d5-19f2-4909-94fd-158d9309deb3'
                    ]
                ]
            ],
            [
                'uuid'             => '613e30a3-bd39-4619-aa5c-1185bd2a8036',
                'type_id'          => 'sap-hana-tenant',
                'servicetemplates' => [
                    '_ids' => [
                        'eea92b1e-3d7b-4922-b6cd-bc0b5ef9c951',
                        '2a645ef8-dbc1-4b4b-8b46-038cccb14f8c',
                        '1118b4bb-d993-468a-a873-b43cd13c265a',
                        'dfb27713-856f-4b8a-a5f6-d24e92635650',
                        '797c9184-ed05-4d57-acf0-ce964732f0f2',
                        '904fd2eb-fd73-45cb-99e9-86b2b46224f2',
                        'dcb1f30b-1663-4b8d-8eb1-321b90abca7e',
                        'a04ce47d-b234-4d93-9da0-b6a205d7cf9c',
                        '24c470c8-ab3b-4537-8f3b-814a0b245292',
                        '0ddd7e66-1532-4c5b-8307-75e1d3b1f370',
                        '91e4568f-ce5d-4330-9855-535b3c9e2359',
                        'd6341ccc-1d82-46e2-bc38-3c136d047cd1',
                        '1401802d-0f14-46bf-b108-5e25dd3b02ac'
                    ]
                ]
            ]
        ];
        return $data;
    }
}
